pub enum FoldStyle {
Fit,
Never,
Always,
Compact,
}Expand description
A style for formatting items
Variants
Fit
Fold items if them can fit in a single line
Never
Never fold items
Always
Always fold items
Compact
Try to fold items except the last one in a single line