Enum typstyle_core::util::FoldStyle
source · pub enum FoldStyle {
Fit,
Single,
Never,
}Expand description
A style for formatting items
Variants
Fit
Fold items if them can fit in a single line
Single
Fold items if there is only one item and it fit in a single line, other wise put each item in a line
Never
Never fold items